@@ -1,5 +1,5 @@
 package WebService::ValidSign::Object::Sender;
-our $VERSION = '0.001';
+our $VERSION = '0.002';
 use Moo;
 
 extends 'WebService::ValidSign::Object';
@@ -42,15 +42,6 @@ sub as_signer {
     return WebService::ValidSign::Object::Signer->new(%result);
 }
 
-around TO_JSON => sub {
-    my $orig = shift;
-    my $self = shift;
-    my $rv = $orig->($self, @_);
-    $rv->{lastName}  = delete $rv->{last_name};
-    $rv->{firstName} = delete $rv->{first_name};
-    return $rv;
-};
-
 __PACKAGE__->meta->make_immutable;
 
 __END__
@@ -65,7 +56,7 @@ WebService::ValidSign::Object::Sender - A ValidSign Sender object
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 AUTHOR
 
